from setuptools import setup

setup(name='ak_s_distributions',
      version='0.1',
      description='Gaussian distributions',
      packages=['ak_s_distributions'],
      author="Mohd Ayan Khan",
      author_email="ayan.k470777@gmail.com",
      zip_safe=False)
